==> wordpress_0.5.4.orig.tar.gz: wordpress-0.5.4.orig/src/WPNetworkEngine.h <==
/*
 * WPNetworkEngine.h
 *
 *  Created on: 4.11.2009
 *      Author: jkal
 */

#ifndef WPNETWORKENGINE_H_
#define WPNETWORKENGINE_H_

#include <QObject>
#include <QMap>
#include <QSet>
#include <QXmlStreamWriter>
#include "WPData.h"
#include <QNetworkRequest>
#include <QDateTime>

QT_BEGIN_HEADER
QT_BEGIN_NAMESPACE

// Forward declarations
class QNetworkReply;
class QNetworkAccessManager;
class QTreeWidget;
class QListWidgetItem;

enum TWPNetworkEngineCommand
	{
	EIdle,
	EGetMainPage,
	EGetRSD,
	EGetUsersBlogs,
	EGetPages,
	EGetPosts,
	EGetCategories,
	EGetTags,
	EGetPageStatuses,
	EGetPostStatuses,
	EGetCommentStatuses,
	EGetComments,
	ENewPage,
	EEditPage,
	EDeletePage,
	ENewComment,
	EEditComment,
	EDeleteComment,
	ENewPost,
	EEditPost,
	EDeletePost,
	EGetGravatar,
	ENewCategory,
        EUploadFile,
        EGetStats
	};

class WPNetworkQueueItem
{
public:
	WPNetworkQueueItem();
	WPNetworkQueueItem(QNetworkReply* aNetworkReply, bool aShowWaitNote, bool aShowErrorNote);
	QNetworkReply* iNetworkReply;
	bool iShowWaitNote;
	bool iShowErrorNote;
};

class WPNetworkEngine: public QObject
{
	Q_OBJECT
	
public:
	enum TGetCommentsStatus
		{
		EAllComments,
		EPendingComments
		};

public:
	WPNetworkEngine();
	virtual ~WPNetworkEngine();
	
	WPDataUsersBlogs* GetAllBlogs() const { return iDataUsersBlogs; };
	WPDataBlog* GetCurrentBlog() const { return iBlogData; };
	WPDataPost* GetPost(QString aPostId);
	WPDataPost* GetLocalDraftPost(QString aPostId);
	WPDataPage* GetLocalDraftPage(QString aPageId);

	// Local data
	void SaveBlogSetup(const QString& aBlogUrl, const QString& aUsername,
			const QString& aPassword, const QString& aNumberOfPosts, bool aResizePhotos);
	bool LoadLocalData();
	void GetGravatar(const QString& aEmail);
	
	void RefreshAll(bool aShowWaitSign = false);
	
	bool DeleteBlog(const QString& aBlogId);
	
	static QString LocalizedTime(const QDateTime& aTimeString);
	static QString LocalizedTime(const QString& aTimeString);
	static QString ShortLocalizedTime(const QString& aTimeString);
	static QString ISO8601Time(const QDateTime& aDateTime);
	
public slots:
	void HandleNetworkData(QNetworkReply *aNetworkReply);
	
	// Functions that update data to network
	void NewPage(const QMap<QString, QString>& aContent, const QString& aPublish,
			const QStringList& aFilenames, const QString& aLocalDraftId);
	void EditPage(const QString& aPageId, const QMap<QString, QString>& aContent,
			const QString& aPublish, const QStringList& aFilenames);
	void DeletePage(const QString& aPageId);
	void NewPost(const QMap<QString, QString>& aContent, const QMap<QString, QStringList>& aListContent,
			const QString& aPublish, const QStringList& aFilenames, const QString& aLocalDraftId);
	void EditPost(const QString& aPostId, const QMap<QString, QString>& aContent,
			const QMap<QString, QStringList>& aListContent,	const QString& aPublish,
			const QStringList& aFilenames);
	void DeletePost(const QString& aPostId, const QString& aPublish);
	void NewComment(const QString& aComment, const QString& aPostId, const QString& aParentComment);
	void EditComment(const QString& aCommentId, const QString& aStatus);
	void DeleteComment(const QString& aCommentId);
	void NewCategory(const QString& aName, const QString& aParentId = "");
	
	// should be private?
	void SaveAllData();
	void OpenBlog(const QString& aBlogId);
	WPDataBlog* GetBlog(const QString& aBlogId);
	
signals:
	void UpdateData(const WPDataBlog& aBlog);
	void UpdateCommentsData(const WPDataBlog& aBlog);
	void UpdatePostData(const WPDataBlog& aBlog);
	void UpdatePageData(const WPDataBlog& aBlog);
	void UpdateCategoryData(const WPDataBlog& aBlog);
	void UpdateData(const WPDataUsersBlogs& aBlogs);
	void GravatarDownloaded(const QString aEmail, const QString& aFilename);
	void GetUserBlogsCompleted(const WPDataBlog& aBlog);
	void TaskStarted(const TWPNetworkEngineCommand& aCommand);
	void TaskFinished(const TWPNetworkEngineCommand& aCommand);
	void ShowErrorNote(const QString& aError);
	
private:
	// Functions that get data from network
	void GetPages(bool aShowWaitSign = true);
	void GetPosts(bool aShowWaitSign = true);
	void GetCategories(bool aShowWaitSign = true);
	void GetTags();
	void GetPageStatuses();
	void GetPostStatuses();
	void GetCommentStatuses();
	void GetComments(bool aShowWaitSign = true, TGetCommentsStatus aStatus = EAllComments,
			const QString& aPostId = "", int aNumberOfComments = 30, int aOffset = 0);
        void GetStats(const QString& postId = "");
	
	void SetCurrentBlog(WPDataBlog& aBlog);
	void GetUsersBlogs(const QUrl& aUrl);
	QString CreateSimpleRequest(const QStringList& aRequestParams);
	static QString XmlEncode(const QString& aSource);
	static void CreateComplexRequest(QString& aRequest, const QString& aMethodName,
			const QStringList& aParamList, const QMap<QString, QString>* aContent,
			const QMap<QString, QStringList>* aListContent, const QString* aPublish);
	static QNetworkRequest CreateNetworkRequest(const QUrl& aUrl, TWPNetworkEngineCommand aType);
	static QByteArray ParseFilenameFromGravatarRequest(const QUrl& aUrl);
	
	void UploadFile(const QString& aFilename);
	void CreateUploadFileRequest(QByteArray& aRequest, const QStringList& aParamList,
	    const QString& aFilename) const;

	QByteArray MD5Hash(const QByteArray& aSource);
	
	void ClearRequestQueue();
	
	void SaveFailedToLocalDrafts();

private: // Data
	QNetworkAccessManager* iNetworkAccessManager;
	WPDataUsersBlogs* iDataUsersBlogs;
	WPDataBlog* iBlogData; // Used to keep track of which blog the request is happening
	
	QList<WPNetworkQueueItem> iCurrentRequests;
	
	QMap<QByteArray, QByteArray> iGravatarHashes;
	QSet<QByteArray> iGravatar404Emails;
	
	// Add blog -related temp variables
	QString iUsername;
	QString iPassword;
	QString iNumberOfPosts;
	bool iResizePhotos;
	
	// Add/edit post -related temp variables. TODO: Encapsulate somewhere!
	QMap<QString, QString> iPostContent;
	QMap<QString, QStringList> iPostListContent;
	QString iPostId;
	QString iLocalDraftId;
	QStringList iFilenames;
	int iFilenameIndex;
	QString iPublishPost;
	bool iUploadPost;
};

QT_END_NAMESPACE
QT_END_HEADER

#endif /* WPNETWORKENGINE_H_ */

==> wordpress_0.5.5.orig.tar.gz: wordpress-0.5.5.orig/src/WPNetworkEngine.h <==
/*
 * WPNetworkEngine.h
 *
 *  Created on: 4.11.2009
 *      Author: jkal
 */

#ifndef WPNETWORKENGINE_H_
#define WPNETWORKENGINE_H_

#include <QObject>
#include <QMap>
#include <QSet>
#include <QXmlStreamWriter>
#include "WPData.h"
#include <QNetworkRequest>
#include <QDateTime>

QT_BEGIN_HEADER
QT_BEGIN_NAMESPACE

// Forward declarations
class QNetworkReply;
class QNetworkAccessManager;
class QTreeWidget;
class QListWidgetItem;

enum TWPNetworkEngineCommand
	{
	EIdle,
	EGetMainPage,
	EGetRSD,
	EGetUsersBlogs,
	EGetPages,
	EGetPosts,
	EGetCategories,
	EGetTags,
	EGetPageStatuses,
	EGetPostStatuses,
	EGetCommentStatuses,
	EGetComments,
	ENewPage,
	EEditPage,
	EDeletePage,
	ENewComment,
	EEditComment,
	EDeleteComment,
	ENewPost,
	EEditPost,
	EDeletePost,
	EGetGravatar,
	ENewCategory,
        EUploadFile,
        EGetStats
	};

class WPNetworkQueueItem
{
public:
	WPNetworkQueueItem();
	WPNetworkQueueItem(QNetworkReply* aNetworkReply, bool aShowWaitNote, bool aShowErrorNote);
	QNetworkReply* iNetworkReply;
	bool iShowWaitNote;
	bool iShowErrorNote;
};

class WPNetworkEngine: public QObject
{
	Q_OBJECT
	
public:
	enum TGetCommentsStatus
		{
		EAllComments,
		EPendingComments
		};

public:
	WPNetworkEngine();
	virtual ~WPNetworkEngine();
	
	WPDataUsersBlogs* GetAllBlogs() const { return iDataUsersBlogs; };
	WPDataBlog* GetCurrentBlog() const { return iBlogData; };
	WPDataPost* GetPost(QString aPostId);
	WPDataPost* GetLocalDraftPost(QString aPostId);
	WPDataPage* GetLocalDraftPage(QString aPageId);

	// Local data
	void SaveBlogSetup(const QString& aBlogUrl, const QString& aUsername,
                        const QString& aPassword, const QString& aNumberOfPosts, bool aResizePhotos, const QString& aApiKey);
	bool LoadLocalData();
	void GetGravatar(const QString& aEmail);
	
	void RefreshAll(bool aShowWaitSign = false);
	
	bool DeleteBlog(const QString& aBlogId);
	
        bool HasApiKey();

	static QString LocalizedTime(const QDateTime& aTimeString);
	static QString LocalizedTime(const QString& aTimeString);
	static QString ShortLocalizedTime(const QString& aTimeString);
	static QString ISO8601Time(const QDateTime& aDateTime);
	
public slots:
	void HandleNetworkData(QNetworkReply *aNetworkReply);
	
	// Functions that update data to network
	void NewPage(const QMap<QString, QString>& aContent, const QString& aPublish,
			const QStringList& aFilenames, const QString& aLocalDraftId);
	void EditPage(const QString& aPageId, const QMap<QString, QString>& aContent,
			const QString& aPublish, const QStringList& aFilenames);
	void DeletePage(const QString& aPageId);
	void NewPost(const QMap<QString, QString>& aContent, const QMap<QString, QStringList>& aListContent,
			const QString& aPublish, const QStringList& aFilenames, const QString& aLocalDraftId);
	void EditPost(const QString& aPostId, const QMap<QString, QString>& aContent,
			const QMap<QString, QStringList>& aListContent,	const QString& aPublish,
			const QStringList& aFilenames);
	void DeletePost(const QString& aPostId, const QString& aPublish);
	void NewComment(const QString& aComment, const QString& aPostId, const QString& aParentComment);
	void EditComment(const QString& aCommentId, const QString& aStatus);
	void DeleteComment(const QString& aCommentId);
	void NewCategory(const QString& aName, const QString& aParentId = "");
        void SetApiKey(const QString& apiKey);
	
	// should be private?
	void SaveAllData();
	void OpenBlog(const QString& aBlogId);
	WPDataBlog* GetBlog(const QString& aBlogId);
	
signals:
	void UpdateData(const WPDataBlog& aBlog);
	void UpdateCommentsData(const WPDataBlog& aBlog);
	void UpdatePostData(const WPDataBlog& aBlog);
	void UpdatePageData(const WPDataBlog& aBlog);
	void UpdateCategoryData(const WPDataBlog& aBlog);
	void UpdateData(const WPDataUsersBlogs& aBlogs);
        void UpdateStats(const WPDataStats& aStats);
	void GravatarDownloaded(const QString aEmail, const QString& aFilename);
	void GetUserBlogsCompleted(const WPDataBlog& aBlog);
	void TaskStarted(const TWPNetworkEngineCommand& aCommand);
	void TaskFinished(const TWPNetworkEngineCommand& aCommand);
	void ShowErrorNote(const QString& aError);
        void ApiKeyChanged();
	
private slots:
       void GetStats(bool aShowWaitSign = true, const QString& table = "");

private:
	// Functions that get data from network
	void GetPages(bool aShowWaitSign = true);
	void GetPosts(bool aShowWaitSign = true);
	void GetCategories(bool aShowWaitSign = true);
	void GetTags();
	void GetPageStatuses();
	void GetPostStatuses();
	void GetCommentStatuses();
	void GetComments(bool aShowWaitSign = true, TGetCommentsStatus aStatus = EAllComments,
			const QString& aPostId = "", int aNumberOfComments = 30, int aOffset = 0);
	
	void SetCurrentBlog(WPDataBlog& aBlog);
	void GetUsersBlogs(const QUrl& aUrl);
	QString CreateSimpleRequest(const QStringList& aRequestParams);
	static QString XmlEncode(const QString& aSource);
	static void CreateComplexRequest(QString& aRequest, const QString& aMethodName,
			const QStringList& aParamList, const QMap<QString, QString>* aContent,
			const QMap<QString, QStringList>* aListContent, const QString* aPublish);
	static QNetworkRequest CreateNetworkRequest(const QUrl& aUrl, TWPNetworkEngineCommand aType);
	static QByteArray ParseFilenameFromGravatarRequest(const QUrl& aUrl);
	
	void UploadFile(const QString& aFilename);
	void CreateUploadFileRequest(QByteArray& aRequest, const QStringList& aParamList,
	    const QString& aFilename) const;

	QByteArray MD5Hash(const QByteArray& aSource);
	
	void ClearRequestQueue();
	
	void SaveFailedToLocalDrafts();

private: // Data
	QNetworkAccessManager* iNetworkAccessManager;
	WPDataUsersBlogs* iDataUsersBlogs;
	WPDataBlog* iBlogData; // Used to keep track of which blog the request is happening
	
	QList<WPNetworkQueueItem> iCurrentRequests;
	
	QMap<QByteArray, QByteArray> iGravatarHashes;
	QSet<QByteArray> iGravatar404Emails;
	
	// Add blog -related temp variables
	QString iUsername;
	QString iPassword;
	QString iNumberOfPosts;
	bool iResizePhotos;
        QString iApiKey;
	
	// Add/edit post -related temp variables. TODO: Encapsulate somewhere!
	QMap<QString, QString> iPostContent;
	QMap<QString, QStringList> iPostListContent;
	QString iPostId;
	QString iLocalDraftId;
	QStringList iFilenames;
	int iFilenameIndex;
	QString iPublishPost;
	bool iUploadPost;
};

QT_END_NAMESPACE
QT_END_HEADER

#endif /* WPNETWORKENGINE_H_ */
